Module astro_float_num::ctx
source · Expand description
Context is used in expressions returning BigFloat.
Structs
Context contains parameters, like rounding mode and precision, as well as constant values, and is used with
expr! macro.Traits
Represents a type that can be used as context in
expr! macro.